#ifdef STM32F0xx
  #include "stm32f0xx_hal_dac_ex.c"
#endif
#ifdef STM32F1xx
  #include "stm32f1xx_hal_dac_ex.c"
#endif
#ifdef STM32F2xx
  #include "stm32f2xx_hal_dac_ex.c"
#endif
#ifdef STM32F3xx
  #include "stm32f3xx_hal_dac_ex.c"
#endif
#ifdef STM32F4xx
  #include "stm32f4xx_hal_dac_ex.c"
#endif
#ifdef STM32F7xx
  #include "stm32f7xx_hal_dac_ex.c"
#endif
#ifdef STM32G0xx
  #include "stm32g0xx_hal_dac_ex.c"
#endif
#ifdef STM32G4xx
  #include "stm32g4xx_hal_dac_ex.c"
#endif
#ifdef STM32H7xx
  #include "stm32h7xx_hal_dac_ex.c"
#endif
#ifdef STM32L0xx
  #include "stm32l0xx_hal_dac_ex.c"
#endif
#ifdef STM32L1xx
  #include "stm32l1xx_hal_dac_ex.c"
#endif
#ifdef STM32L4xx
  #include "stm32l4xx_hal_dac_ex.c"
#endif
#ifdef STM32L5xx
  #include "stm32l5xx_hal_dac_ex.c"
#endif
#ifdef STM32MP1xx
  #include "stm32mp1xx_hal_dac_ex.c"
#endif
